[cig-commits] commit: Merge with 1.4.x

Mercurial hg at geodynamics.org
Fri Feb 5 12:09:53 PST 2010


changeset:   586:5b2e78ffb9c7
tag:         tip
parent:      583:ceedf650bf57
parent:      585:56334edd7a54
user:        Walter Landry <wlandry at caltech.edu>
date:        Thu Feb 04 15:20:30 2010 -0800
files:       Mesh/src/Mesh_Algorithms.c Shape/src/PolygonShape.c Utils/tests/AllNodesVCSuite.c Utils/tests/CompositeVCSuite.c Utils/tests/CornerVCSuite.c Utils/tests/DofLayoutSuite.c Utils/tests/WallVCSuite.c
description:
Merge with 1.4.x


diff -r ceedf650bf57 -r 5b2e78ffb9c7 Geometry/src/ComplexVectorMath.c
--- a/Geometry/src/ComplexVectorMath.c	Mon Feb 01 02:21:24 2010 -0800
+++ b/Geometry/src/ComplexVectorMath.c	Thu Feb 04 15:20:30 2010 -0800
@@ -474,7 +474,7 @@ void StGermain_ComplexVectorNormalise(Cm
 
 #define STGERMAIN_COMPLEXVECTOR_ONE_THIRD 0.3333333333333333333
 
-/** StGermain_ComplexTriangleCentroid Calculates the position vector to the centroid of a triangle whose verticies are given by position vectors 
+/** StGermain_ComplexTriangleCentroid Calculates the position vector to the centroid of a triangle whose vertices are given by position vectors 
 Position vectors have to be of size dim Cmplx */
 void StGermain_ComplexTriangleCentroid( Cmplx* centroid, Cmplx* pos0, Cmplx* pos1, Cmplx* pos2, Index dim) {
 	Cmplx tmp;
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Geometry/src/VectorMath.c
--- a/Geometry/src/VectorMath.c	Mon Feb 01 02:21:24 2010 -0800
+++ b/Geometry/src/VectorMath.c	Thu Feb 04 15:20:30 2010 -0800
@@ -345,7 +345,7 @@ void StGermain_NormalToPlane( double* no
 }
 
 #define ONE_THIRD 0.3333333333333333333
-/** Calculates the position vector to the centroid of a triangle whose verticies are given by position vectors 
+/** Calculates the position vector to the centroid of a triangle whose vertices are given by position vectors 
 Position vectors have to be of size dim doubles */
 void StGermain_TriangleCentroid( double* centroid, double* pos0, double* pos1, double* pos2, Index dim) {
 
@@ -366,7 +366,7 @@ void StGermain_TriangleCentroid( double*
 	}
 }
 
-/** Calculates the area of a triangle whose verticies are given by position vectors 
+/** Calculates the area of a triangle whose vertices are given by position vectors 
 Position vectors have to be of size dim doubles 
 Only works for dim == 2 or dim == 3
 */
@@ -391,7 +391,7 @@ double StGermain_TriangleArea( double* p
 /** StGermain_ConvexQuadrilateralArea - See Eric W. Weisstein. "Quadrilateral." 
  * From MathWorld--A Wolfram Web Resource. http://mathworld.wolfram.com/Quadrilateral.html
  * Area = \frac{1}{2}| p \times q | where p and q are diagonals of a convex polygon
- * This function will not work for dim > 3 and verticies have to be given in a winding direction
+ * This function will not work for dim > 3 and vertices have to be given in a winding direction
 */
 double StGermain_ConvexQuadrilateralArea( double* vertexCoord1, double* vertexCoord2, double* vertexCoord3, double* vertexCoord4, Dimension_Index dim ) {
 	Coord diagonal1;	
@@ -445,7 +445,7 @@ void StGermain_AverageCoord( double* coo
 	/* Initialise */
 	coord[ I_AXIS ] = coord[ J_AXIS ] = coord[ K_AXIS ] = 0.0;
 
-	/* Sum verticies */
+	/* Sum vertices */
 	for ( coord_I = 0 ; coord_I < count ; coord_I++ ) {
 		coord[ I_AXIS ] += coordList[ coord_I ][ I_AXIS ];
 		coord[ J_AXIS ] += coordList[ coord_I ][ J_AXIS ];
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Shape/src/ConvexHull.c
--- a/Shape/src/ConvexHull.c	Mon Feb 01 02:21:24 2010 -0800
+++ b/Shape/src/ConvexHull.c	Thu Feb 04 15:20:30 2010 -0800
@@ -211,10 +211,10 @@ void _ConvexHull_AssignFromXML( void* co
 	
 	_Stg_Shape_AssignFromXML( self, cf, data );
 
-	optionsList = Dictionary_Get( dictionary, (Dictionary_Entry_Key)"verticies"  );
+	optionsList = Dictionary_Get( dictionary, (Dictionary_Entry_Key)"vertices"  );
 	Journal_Firewall( optionsList != NULL, 
 		Journal_Register( Error_Type, (Name)self->type  ),
-		"In func %s: The list 'verticies' specifying the convexHull is NULL.\n", __func__);
+		"In func %s: The list 'vertices' specifying the convexHull is NULL.\n", __func__);
 
 	vertexCount = Dictionary_Entry_Value_GetCount(optionsList);
 	Journal_Firewall( ( self->dim == 2 && vertexCount < 4 ) || ( self->dim == 3 && vertexCount < 5 ),
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Shape/src/ConvexHull.meta
--- a/Shape/src/ConvexHull.meta	Mon Feb 01 02:21:24 2010 -0800
+++ b/Shape/src/ConvexHull.meta	Thu Feb 04 15:20:30 2010 -0800
@@ -29,7 +29,7 @@
 <![CDATA[
 	<struct name="shape">
 		<param name="Type">ConvexHull</param>
-		<list name="verticies">
+		<list name="vertices">
 			<asciidata>
 				<columnDefinition name = "x" type="double"/>
 				<columnDefinition name = "y" type="double"/>
@@ -45,7 +45,7 @@
 	<!-- In 3D -->
 	<struct name="shape">
 		<param name="Type">ConvexHull</param>
-		<list name="verticies">
+		<list name="vertices">
 			<asciidata>
 				<columnDefinition name = "x" type="double"/>
 				<columnDefinition name = "y" type="double"/>
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Shape/tests/input/testConvexHull2D.xml
--- a/Shape/tests/input/testConvexHull2D.xml	Mon Feb 01 02:21:24 2010 -0800
+++ b/Shape/tests/input/testConvexHull2D.xml	Thu Feb 04 15:20:30 2010 -0800
@@ -8,7 +8,7 @@
 		<struct name="shape">
 			<param name="Type">ConvexHull</param>
 			<param name="startZ">0.3</param>
-			<list name="verticies">
+			<list name="vertices">
 				<asciidata>
 					<columnDefinition name = "x" type="double"/>
 					<columnDefinition name = "y" type="double"/>
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Shape/tests/input/testConvexHull3D.xml
--- a/Shape/tests/input/testConvexHull3D.xml	Mon Feb 01 02:21:24 2010 -0800
+++ b/Shape/tests/input/testConvexHull3D.xml	Thu Feb 04 15:20:30 2010 -0800
@@ -8,7 +8,7 @@
 		<struct name="shape">
 			<param name="Type">ConvexHull</param>
 			<param name="startZ">0.3</param>
-			<list name="verticies">
+			<list name="vertices">
 				<asciidata>
 					<columnDefinition name = "x" type="double"/>
 					<columnDefinition name = "y" type="double"/>
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Shape/tests/input/testPolygonShape.xml
--- a/Shape/tests/input/testPolygonShape.xml	Mon Feb 01 02:21:24 2010 -0800
+++ b/Shape/tests/input/testPolygonShape.xml	Thu Feb 04 15:20:30 2010 -0800
@@ -8,7 +8,7 @@
 		<struct name="shape">
 			<param name="Type">PolygonShape</param>
 			<param name="startZ">0.3</param>
-			<list name="verticies">
+			<list name="vertices">
 				<asciidata>
 					<columnDefinition name = "x" type="double"/>
 					<columnDefinition name = "y" type="double"/>
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Swarm/src/LineParticleLayout.meta
--- a/Swarm/src/LineParticleLayout.meta	Mon Feb 01 02:21:24 2010 -0800
+++ b/Swarm/src/LineParticleLayout.meta	Thu Feb 04 15:20:30 2010 -0800
@@ -26,10 +26,10 @@
 		<param name="Description">This is the total number of particles specified throughout the global domain.</param>
 	</struct>
 	<struct>
-		<param name="Name">verticies</param>
+		<param name="Name">vertices</param>
 		<param name="Type">list</param>
 		<param name="ElementType">struct of doubles with name x, y, z</param>
-		<param name="Description">A list of verticies that define the line segments on which the particles will be distributed.</param>
+		<param name="Description">A list of vertices that define the line segments on which the particles will be distributed.</param>
 	</struct>	
 
 </list>
@@ -41,7 +41,7 @@
 	<struct name="particleLayoutExample1">
 		<param name="Type">LineParticleLayout</param>
 		<param name="totalInitialParticles">6</param>
-		<list name="verticies">
+		<list name="vertices">
 			<asciidata>		
 				<columnDefinition name = "x" type="double"/>
 				<columnDefinition name = "y" type="double"/>
@@ -55,7 +55,7 @@
 	<struct name="particleLayoutExample2">
 		<param name="Type">LineParticleLayout</param>
 		<param name="totalInitialParticles">6</param>
-		<list name="verticies">
+		<list name="vertices">
 			<struct>
 				<param name="x">0.5</param>
 				<param name="y">0.1</param>
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Swarm/tests/input/testLineParticleLayout.xml
--- a/Swarm/tests/input/testLineParticleLayout.xml	Mon Feb 01 02:21:24 2010 -0800
+++ b/Swarm/tests/input/testLineParticleLayout.xml	Thu Feb 04 15:20:30 2010 -0800
@@ -10,7 +10,7 @@
 		<struct name="particleLayout">
 			<param name="Type">LineParticleLayout</param>
 			<param name="totalInitialParticles">20</param>
-			<list name="verticies">
+			<list name="vertices">
 				<asciidata>
 					<columnDefinition name = "x" type="double"/>
 					<columnDefinition name = "y" type="double"/>



More information about the CIG-COMMITS mailing list
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Shape/src/PolygonShape.c
--- a/Shape/src/PolygonShape.c	Mon Feb 01 02:21:24 2010 -0800
+++ b/Shape/src/PolygonShape.c	Thu Feb 04 15:20:30 2010 -0800
@@ -196,12 +196,12 @@ void _PolygonShape_AssignFromXML( void* 
 	        self->name, perpendicularAxisName );
 	}	
 
-	optionsList = Dictionary_Get( dictionary, (Dictionary_Entry_Key)"verticies" );
+	optionsList = Dictionary_Get( dictionary, (Dictionary_Entry_Key)"vertices" );
 	
 	vertexCount = Dictionary_Entry_Value_GetCount(optionsList );
 	Journal_Firewall( vertexCount >= 3, errorStream, 
-			"To few verticies given in trying to build shape '%s' named '%s'.\n"
-			"A polygon needs at least three verticies.\n",
+			"Too few vertices given in trying to build shape '%s' named '%s'.\n"
+			"A polygon needs at least three vertices.\n",
 			self->type, self->name );
 
 	/* Allocate space */
@@ -263,7 +263,7 @@ void _PolygonShape_Destroy( void* polygo
 */
 /* Algorithm describe Paul Bourke's page http://astronomy.swin.edu.au/~pbourke/geometry/insidepoly/ (see solution 2)
  *
  * Algorithm works by summing the angles between the test coordinate and each pair of verticies that make up an edge 
  * in the polygon. An inside point will give an angle of 2pi and and outside point will give an angle of 0 */
 
 Bool _PolygonShape_IsCoordInside( void* polygon, Coord coord ) {
@@ -289,7 +289,7 @@ Bool _PolygonShape_IsCoordInside( void* 
 		return False;	
 
 	for ( vertex_I = 0 ; vertex_I < vertexCount ; vertex_I++ ) {
 		/* Get verticies of current edge */
 		startVertex = vertexList[ vertex_I ];
 		endVertex   = vertexList[ (vertex_I + 1) % vertexCount ];
 
@@ -263,7 +263,7 @@ void _PolygonShape_Destroy( void* polygo
 /* Algorithm describe Paul Bourke's page http://astronomy.swin.edu.au/~pbourke/geometry/insidepoly/ (see solution 2)
  *
- * Algorithm works by summing the angles between the test coordinate and each pair of verticies that make up an edge 
+ * Algorithm works by summing the angles between the test coordinate and each pair of vertices that make up an edge 
  * in the polygon. An inside point will give an angle of 2pi and and outside point will give an angle of 0 */
 
@@ -289,7 +289,7 @@ Bool _PolygonShape_IsCoordInside( void* 
 
 	for ( vertex_I = 0 ; vertex_I < vertexCount ; vertex_I++ ) {
-		/* Get verticies of current edge */
+		/* Get vertices of current edge */
 		startVertex = vertexList[ vertex_I ];
 		endVertex   = vertexList[ (vertex_I + 1) % vertexCount ];
diff -r ceedf650bf57 -r 5b2e78ffb9c7 Swarm/src/LineParticleLayout.c
--- a/Swarm/src/LineParticleLayout.c	Mon Feb 01 02:21:24 2010 -0800
+++ b/Swarm/src/LineParticleLayout.c	Thu Feb 04 15:20:30 2010 -0800
@@ -208,8 +208,8 @@ void _LineParticleLayout_AssignFromXML( 
 
 	dim = Stg_ComponentFactory_GetRootDictUnsignedInt( cf, (Dictionary_Entry_Key)"dim", 0  );
 
-	/* Read list of verticies of each of the different line segments from the dictionary */
-	list = Dictionary_Get( dictionary, (Dictionary_Entry_Key)"verticies" );
+	/* Read list of vertices of each of the different line segments from the dictionary */
+	list = Dictionary_Get( dictionary, (Dictionary_Entry_Key)"vertices" );
 	vertexCount = Dictionary_Entry_Value_GetCount( list  );
 	vertexList = Memory_Alloc_Array( Coord , vertexCount, "Vertex Array" );
 	memset( vertexList, 0, vertexCount * sizeof(Coord) );